@@ -21,6 +21,7 @@ from haversine import haversine, Unit
 from rich.live import Live
 from rich.table import Table
 
+from dotbot import GATEWAY_ADDRESS_DEFAULT
 from dotbot.hdlc import HDLCHandler, HDLCState, hdlc_encode
 from dotbot.protocol import (
     ProtocolPayload,
@@ -73,6 +74,7 @@ class ControllerSettings:  # pylint: disable=too-many-instance-attributes
     gw_address: str
     swarm_id: str
     webbrowser: bool = False
+    table: bool = False
     verbose: bool = False
 
 
@@ -125,7 +127,7 @@ class ControllerBase(ABC):
             version=PROTOCOL_VERSION,
         )
         self.settings = settings
-        self.hdlc_handler = HDLCHandler()
+        self.hdlc_handler = HDLCHandler(verbose=settings.verbose)
         self.serial = None
         self.websockets = []
         self.lh2_manager = LighthouseManager()
@@ -235,11 +237,14 @@ class ControllerBase(ABC):
                 try:
                     payload = ProtocolPayload.from_bytes(payload)
                 except ProtocolPayloadParserException:
-                    print(f"Cannot parse payload '{payload}'")
+                    if self.settings.verbose is True:
+                        print(f"Cannot parse payload '{payload}'")
                     return
                 self.handle_received_payload(payload)
 
-    def handle_received_payload(self, payload: ProtocolPayload):
+    def handle_received_payload(
+        self, payload: ProtocolPayload
+    ):  # pylint:disable=too-many-branches
         """Handle a received payload."""
         # Controller is not interested by command messages received
         if payload.payload_type in [
@@ -247,9 +252,12 @@ class ControllerBase(ABC):
             PayloadType.CMD_RGB_LED,
         ]:
             return
-        if self.settings.verbose:
+        if self.settings.verbose is True:
             print(payload)
         source = hexlify(int(payload.header.source).to_bytes(8, "big")).decode()
+        if source == GATEWAY_ADDRESS_DEFAULT:
+            print(f"Invalid source in payload type {payload.payload_type}")
+            return
         dotbot = DotBotModel(
             address=source,
             application=payload.header.application,
@@ -420,9 +428,10 @@ class ControllerBase(ABC):
                 asyncio.create_task(self._open_webbrowser()),
                 asyncio.create_task(self._start_serial()),
                 asyncio.create_task(self._dotbots_status_refresh()),
-                asyncio.create_task(self._dotbots_table_refresh()),
                 asyncio.create_task(self.start()),
             ]
+            if self.settings.table is True:
+                tasks.append(asyncio.create_task(self._dotbots_table_refresh()))
             await asyncio.gather(*tasks)
         except (
             SystemExit,
