@@ -9,10 +9,10 @@ import { DotBotsMap } from "./DotBotsMap";
 import { SailBotsMap } from "./SailBotsMap";
 import {
   apiUpdateActiveDotbotAddress, apiFetchActiveDotbotAddress,
-  apiFetchDotbots, apiUpdateRgbLed, apiUpdateMoveRaw, apiUpdateControlMode,
-  apiUpdateWaypoints, inactiveAddress,
+  apiFetchDotbots, apiUpdateRgbLed, apiUpdateMoveRaw,
+  apiUpdateWaypoints, apiClearPositionsHistory, inactiveAddress,
 } from "./rest";
-import { ApplicationType, ControlModeType, gps_distance_threshold, lh2_distance_threshold, maxWaypoints } from "./constants";
+import { ApplicationType, gps_distance_threshold, lh2_distance_threshold, maxWaypoints } from "./constants";
 import { gps_distance, lh2_distance } from "./helpers";
 
 
@@ -36,10 +36,6 @@ const DotBotAccordionItem = (props) => {
     rgbColor = `rgb(${props.dotbot.rgb_led.red}, ${props.dotbot.rgb_led.green}, ${props.dotbot.rgb_led.blue})`
   }
 
-  const autoModeClicked = async (event) => {
-    await props.updateAutoMode(props.dotbot.address, props.dotbot.application, event.target.checked);
-  }
-
   useEffect(() => {
     if (props.dotbot.rgb_led) {
       setColor({ r: props.dotbot.rgb_led.red, g: props.dotbot.rgb_led.green, b: props.dotbot.rgb_led.blue })
@@ -96,18 +92,22 @@ const DotBotAccordionItem = (props) => {
               </div>
             </div>
           </div>
-          {props.dotbot.lh2_position &&
-            <div className="d-flex mx-auto">
-              <div className="form-check">
-                <input className="form-check-input" type="checkbox" id="flexCheckModeAuto" defaultChecked={props.dotbot.mode} onChange={autoModeClicked} />
-                <label className="form-check-label" htmlFor="flexCheckModeAuto">Autonomous mode</label>
+          {props.dotbot.waypoints && props.dotbot.waypoints.length > 0 &&
+          <>
+            <div className="d-flex mx-auto card">
+              <div className="card-body p-1">
+                <p className="m-0 p-0">
+                  <span>Autonomous mode: </span>
+                  <button className="btn btn-primary btn-sm m-1" onClick={async () => props.applyWaypoints(props.dotbot.address, props.dotbot.application)}>Start</button>
+                  <button className="btn btn-primary btn-sm m-1" onClick={async () => props.clearWaypoints(props.dotbot.address, props.dotbot.application)}>Clear</button>
+                </p>
               </div>
             </div>
+          </>
           }
-          {props.dotbot.waypoints && props.dotbot.waypoints.length > 0 &&
-            <div className="d-flex mx-auto">
-              <button className="btn btn-primary btn-sm m-1" onClick={async () => props.applyWaypoints(props.dotbot.address, props.dotbot.application)}>Apply waypoints</button>
-              <button className="btn btn-primary btn-sm m-1" onClick={async () => props.clearWaypoints(props.dotbot.address, props.dotbot.application)}>Clear waypoints</button>
+          {props.dotbot.position_history && props.dotbot.position_history.length > 0 &&
+            <div className="d-flex me-auto">
+              <button className="btn btn-primary btn-sm m-1" onClick={async () => props.clearPositionsHistory(props.dotbot.address)}>Clear positions history</button>
             </div>
           }
         </div>
@@ -140,10 +140,6 @@ const SailBotItem = (props) => {
     setActive(newSailValue !== 0);
   };
 
-  const autoModeClicked = async (event) => {
-    await props.updateAutoMode(props.dotbot.address, props.dotbot.application, event.target.checked);
-  }
-
   useInterval(async () => {
     if (rudderValue === 0 && sailValue === 0) {
       setActive(false);
@@ -200,18 +196,22 @@ const SailBotItem = (props) => {
               <button className="btn btn-primary m-1" onClick={applyColor}>Apply color</button>
             </div>
           </div>
-          {props.dotbot.gps_position &&
-            <div className="d-flex mx-auto">
-              <div className="form-check">
-                <input className="form-check-input" type="checkbox" id="flexCheckModeAuto" defaultChecked={props.dotbot.mode} onChange={autoModeClicked} />
-                <label className="form-check-label" htmlFor="flexCheckModeAuto">Autonomous mode</label>
-              </div>
-            </div>
-          }
           {props.dotbot.waypoints && props.dotbot.waypoints.length > 0 &&
-            <div className="d-flex mx-auto">
-              <button className="btn btn-primary btn-sm m-1" onClick={async () => props.applyWaypoints(props.dotbot.address, ApplicationType.SailBot)}>Apply waypoints</button>
-              <button className="btn btn-primary btn-sm m-1" onClick={async () => props.clearWaypoints(props.dotbot.address, ApplicationType.SailBot)}>Clear waypoints</button>
+            <>
+              <div className="d-flex mx-auto card">
+                <div className="card-body p-1">
+                  <p className="m-0 p-0">
+                    <span>Autonomous mode: </span>
+                    <button className="btn btn-primary btn-sm m-1" onClick={async () => props.applyWaypoints(props.dotbot.address, ApplicationType.SailBot)}>Start</button>
+                    <button className="btn btn-primary btn-sm m-1" onClick={async () => props.clearWaypoints(props.dotbot.address, ApplicationType.SailBot)}>Stop</button>
+                  </p>
+                </div>
+              </div>
+            </>
+          }
+          {props.dotbot.position_history && props.dotbot.position_history.length > 0 &&
+            <div className="d-flex me-auto">
+              <button className="btn btn-primary btn-sm m-1" onClick={async () => props.clearPositionsHistory(props.dotbot.address)}>Clear positions history</button>
             </div>
           }
         </div>
@@ -232,18 +232,6 @@ const DotBots = () => {
   }, [setActiveDotbot]
   );
 
-  const updateAutoMode = async (address, application, mode) => {
-    const newMode = mode ? ControlModeType.Auto : ControlModeType.Manual;
-    await apiUpdateControlMode(address, application, newMode);
-    let dotbotsTmp = dotbots.slice();
-    for (let idx = 0; idx < dotbots.length; idx++) {
-      if (dotbots[idx].address === address) {
-        dotbotsTmp[idx].mode = newMode;
-        setDotbots(dotbotsTmp);
-      }
-    }
-  };
-
   const updateShowHistory = (show, application) => {
     if (application === ApplicationType.SailBot) {
       setShowSailBotHistory(show);
@@ -272,10 +260,6 @@ const DotBots = () => {
     }
 
     const dotbot = activeDotbots[0];
-    if (dotbot.mode !== ControlModeType.Auto) {
-      // Do nothing if dotbot is in manual mode
-      return;
-    }
 
     // Limit number of waypoints to maxWaypoints
     if (dotbot.waypoints.length >= maxWaypoints) {
@@ -337,6 +321,18 @@ const DotBots = () => {
     }
   };
 
+  const clearPositionsHistory = async (address) => {
+    let dotbotsTmp = dotbots.slice();
+    for (let idx = 0; idx < dotbots.length; idx++) {
+      if (dotbots[idx].address === address) {
+        dotbotsTmp[idx].position_history = [];
+        await apiClearPositionsHistory(address);
+        setDotbots(dotbotsTmp);
+        return;
+      }
+    }
+  };
+
   const onWsOpen = () => {
     console.log('websocket opened');
     fetchDotBots();
@@ -436,9 +432,9 @@ const DotBots = () => {
                       dotbot={dotbot}
                       active={activeDotbot}
                       updateActive={updateActive}
-                      updateAutoMode={updateAutoMode}
                       applyWaypoints={applyWaypoints}
                       clearWaypoints={clearWaypoints}
+                      clearPositionsHistory={clearPositionsHistory}
                       refresh={fetchDotBots}
                     />
                   )
@@ -449,10 +445,26 @@ const DotBots = () => {
         </div>
         <div className="col col-xxl-6">
           <div className="d-block d-md-none m-1">
-            <DotBotsMap dotbots={dotbots.filter(dotbot => dotbot.application === ApplicationType.DotBot)} active={activeDotbot} updateActive={updateActive} showHistory={showDotBotHistory} updateShowHistory={updateShowHistory} mapClicked={mapClicked} mapSize={350} />
+            <DotBotsMap
+              dotbots={dotbots.filter(dotbot => dotbot.application === ApplicationType.DotBot)}
+              active={activeDotbot}
+              updateActive={updateActive}
+              showHistory={showDotBotHistory}
+              updateShowHistory={updateShowHistory}
+              mapClicked={mapClicked}
+              mapSize={350}
+            />
           </div>
           <div className="d-none d-md-block m-1">
-            <DotBotsMap dotbots={dotbots.filter(dotbot => dotbot.application === ApplicationType.DotBot)} active={activeDotbot} updateActive={updateActive} showHistory={showDotBotHistory} updateShowHistory={updateShowHistory} mapClicked={mapClicked} mapSize={650} />
+            <DotBotsMap
+              dotbots={dotbots.filter(dotbot => dotbot.application === ApplicationType.DotBot)}
+              active={activeDotbot}
+              updateActive={updateActive}
+              showHistory={showDotBotHistory}
+              updateShowHistory={updateShowHistory}
+              mapClicked={mapClicked}
+              mapSize={650}
+            />
           </div>
         </div>
       </div>
@@ -472,9 +484,9 @@ const DotBots = () => {
                       dotbot={dotbot}
                       active={activeDotbot}
                       updateActive={updateActive}
-                      updateAutoMode={updateAutoMode}
                       applyWaypoints={applyWaypoints}
                       clearWaypoints={clearWaypoints}
+                      clearPositionsHistory={clearPositionsHistory}
                       refresh={fetchDotBots}
                     />
                   )
@@ -485,10 +497,24 @@ const DotBots = () => {
         </div>
         <div className="col col-xxl-6">
           <div className="d-block d-md-none m-1">
-            <SailBotsMap sailbots={dotbots.filter(dotbot => dotbot.application === ApplicationType.SailBot)} active={activeDotbot} showHistory={showSailBotHistory} updateShowHistory={updateShowHistory} mapClicked={mapClicked} mapSize={350} />
+            <SailBotsMap
+              sailbots={dotbots.filter(dotbot => dotbot.application === ApplicationType.SailBot)}
+              active={activeDotbot}
+              showHistory={showSailBotHistory}
+              updateShowHistory={updateShowHistory}
+              mapClicked={mapClicked}
+              mapSize={350}
+            />
           </div>
           <div className="d-none d-md-block m-1">
-            <SailBotsMap sailbots={dotbots.filter(dotbot => dotbot.application === ApplicationType.SailBot)} active={activeDotbot} showHistory={showSailBotHistory} updateShowHistory={updateShowHistory} mapClicked={mapClicked} mapSize={650} />
+            <SailBotsMap
+              sailbots={dotbots.filter(dotbot => dotbot.application === ApplicationType.SailBot)}
+              active={activeDotbot}
+              showHistory={showSailBotHistory}
+              updateShowHistory={updateShowHistory}
+              mapClicked={mapClicked}
+              mapSize={650}
+            />
           </div>
         </div>
       </div>
