@@ -1,7 +1,5 @@
 """Test module for the lighthouse2 API."""
 
-from unittest.mock import patch
-
 import pytest
 
 from dotbot.lighthouse2 import calculate_camera_point, lh2_raw_data_to_counts
@@ -38,13 +36,6 @@ def test_raw_data_to_counts():
     assert lh2_raw_data_to_counts(raw_data) == EXPECTED_COUNTS
 
 
-@patch("os.path.exists")
-def test_raw_data_to_counts_no_lib(lib_exists):
-    lib_exists.return_value = False
-    raw_data = Lh2RawData(locations=LOCATIONS)
-    assert lh2_raw_data_to_counts(raw_data) == EXPECTED_COUNTS
-
-
 def test_camera_points():
     assert calculate_camera_point(49341, 85887, 1) == pytest.approx(
         (-0.4255775370509014, 0.15468717476270966)
