@@ -7,7 +7,7 @@ import sys
 from hatchling.builders.hooks.plugin.interface import BuildHookInterface
 
 sys.path.append(os.path.dirname(__file__))
-from pydotbot_utils import build_frontend  # noqa: E402
+from pydotbot_utils import build_frontend, build_lh2  # noqa: E402
 
 
 class CustomBuildHook(BuildHookInterface):
@@ -16,3 +16,4 @@ class CustomBuildHook(BuildHookInterface):
     def initialize(self, _, __):
         """Will be called before creating the source archive."""
         build_frontend(self.root)
+        build_lh2(self.root)
